@@ -40,6 +40,12 @@ from sagemaker_studio_sparkmagic_lib.kerberos import write_krb_conf
 from ..resource.emr.auth import ClusterSessionCredentialsProvider
 from ..resource.emr.auth import ClusterAuthUtils
 from ..resource.emr.emr_client import get_emr_client
+from ..utils.exceptions import (
+    LivyConnectionError,
+    MissingParametersError,
+    InvalidParameterError,
+    InvalidConfigError,
+)
 from ..utils.arn_util import RoleArnValidator
 from ..utils.boto_client_utils import get_boto3_session
 from ..utils.constants import (
@@ -149,19 +155,19 @@ def _prepare_livy_endpoint(emr_cluster, livy_port):
         # Check public dns connectivity only if connection to private dns fails
         public_livy_host_name = emr_cluster.primary_node_public_dns_name()
         if is_blank(public_livy_host_name):
-            raise RuntimeError(
+            raise LivyConnectionError(
                 f"Cannot connect to livy service at {private_livy_host_name}:{livy_port}"
             )
 
         if check_host_and_port(public_livy_host_name, livy_port):
             # Fail if public dns is accessible but not configured to use SSL
             if not is_ssl_enabled(public_livy_host_name, livy_port):
-                raise RuntimeError(
+                raise LivyConnectionError(
                     f"Livy is available at {public_livy_host_name}:{livy_port}, but not configured to use HTTPS. Please setup livy with HTTPS: https://docs.aws.amazon.com/emr/latest/ReleaseGuide/enabling-https.html"
                 )
             livy_host_name = public_livy_host_name
         else:
-            raise RuntimeError(
+            raise LivyConnectionError(
                 f"Cannot connect to livy service at {private_livy_host_name}:{livy_port} or {public_livy_host_name}:{livy_port}"
             )
 
@@ -254,7 +260,7 @@ class IpythonWidgetBasedAuthProvider:
     ):
         # If the Notebook is run in headless mode and a --secret parameter is not provided, we raise an exception to notify the same.
         if "SM_JOB_DEF_VERSION" in os.environ:
-            raise ValueError(
+            raise MissingParametersError(
                 "A --secret parameter needs to be added to run the Notebook in Headless mode"
             )
         else:
@@ -359,7 +365,7 @@ def _handle_kerberos_connectivity_failure(args, completed_process):
     )
 
     if error_message:
-        raise Exception(
+        raise InvalidParameterError(
             "Failed to generate kerberos token using provided credentials. \n{} \n{}".format(
                 error_message, str(completed_process.stdout, "UTF-8")
             )
@@ -500,15 +506,15 @@ def _get_livy_port_from_cluster_configuration(emr_cluster):
 
 def _validate_emr_args(args, usage, kernel_name):
     if args.cluster_id is None:
-        raise ValueError(
+        raise MissingParametersError(
             "Missing required argument '{}'. {}".format("--cluster-id", usage)
         )
     elif args.auth_type is None:
-        raise ValueError(
+        raise MissingParametersError(
             "Missing required argument '{}'. {}".format("--auth-type", usage)
         )
     elif args.auth_type not in AUTH_TYPE_SET:
-        raise Exception(
+        raise MissingParametersError(
             "Invalid auth type, supported auth types are '{}'. {}".format(
                 AUTH_TYPE_SET, usage
             )
@@ -523,13 +529,13 @@ def _validate_emr_args(args, usage, kernel_name):
     # Only IPython kernel needs language option support
     if kernel_name == IPYTHON_KERNEL:
         if args.language is None:
-            raise ValueError(
+            raise MissingParametersError(
                 "Missing required argument '{}' for IPython kernel. {}".format(
                     "--language", usage
                 )
             )
         elif args.language not in LANGUAGES_SUPPORTED:
-            raise Exception(
+            raise InvalidParameterError(
                 "Invalid language, supported languages are '{}'. {}".format(
                     LANGUAGES_SUPPORTED, usage
                 )
@@ -553,9 +559,7 @@ def _initiate_emr_connect(args, cluster, emr_client, boto_session, kernel_name):
         emr_boto_config = BotocoreConfig(user_agent_extra="sagemaker-analytics")
 
         # Before EMR IAM Passthrough is GA, use emr-iam-passthrough-gcsc as service.
-        emr_gcsc_client = boto_session.client(
-            "emr-iam-passthrough-gcsc", config=emr_boto_config
-        )
+        emr_gcsc_client = boto_session.client("emr", config=emr_boto_config)
 
         credentials = (
             ClusterSessionCredentialsProvider().get_cluster_session_credentials(
@@ -665,14 +669,14 @@ def _validate_cluster_auth_with_auth_type_provided(auth_type, emr_cluster):
         or (auth_type == AUTH_TYPE_KERBEROS and is_cluster_ldap_authenticated)
         or (auth_type == AUTH_TYPE_KERBEROS and is_cluster_no_auth)
     ):
-        raise Exception(
+        raise InvalidParameterError(
             "Cluster auth type does not match provided auth {}".format(auth_type)
         )
 
 
 def _check_required_args(args, usage):
     if args is None or args.command is None or len(args.command) != 2:
-        raise Exception(
+        raise MissingParametersError(
             "Please provide service name and operation to perform. {}".format(usage)
         )
 
@@ -792,9 +796,13 @@ class SagemakerAnalytics(Magics):
                     service_logger=sagemaker_analytics_service_logger,
                 )
             else:
-                raise Exception("Operation '{}' not found. {}".format(operation, usage))
+                raise InvalidParameterError(
+                    "Operation '{}' not found. {}".format(operation, usage)
+                )
         else:
-            raise Exception("Service '{}' not found. {}".format(service, usage))
+            raise InvalidParameterError(
+                "Service '{}' not found. {}".format(service, usage)
+            )
 
 
 @records_service_metrics
@@ -857,7 +865,7 @@ def _list_instance_groups(emr_client, cluster_id):
                 cluster_id, ce.response
             )
         )
-        raise ValueError(
+        raise InvalidConfigError(
             "Unable to list instance groups for EMR cluster(Id: {0}) using ListInstanceGroups API. Error: {1}".format(
                 cluster_id, ce.response["Error"]
             )
