@@ -1,4 +1,3 @@
-import boto3
 import pkg_resources
 
 from ..utils.constants import EXTENSION_NAME
@@ -8,7 +7,9 @@ from ..utils.client_factory import ClientFactory
 class ResourceMetadata:
     def __init__(self):
         try:
-            self.library_version = pkg_resources.require(EXTENSION_NAME)[0].version
+            self.library_version = pkg_resources.get_distribution(
+                EXTENSION_NAME
+            ).version
         except Exception as e:
             self.library_version = "UNKNOWN"
 
