@@ -1,3 +1,4 @@
+import botocore
 import time
 import json
 from enum import Enum
@@ -8,6 +9,7 @@ from .constants import (
     SERVICE,
     AUTH_TYPE_SET_FOR_LOGGING,
 )
+from .exceptions import AnalyticsLibError
 
 from ..resource.resource_metadata import ResourceMetadata
 from ..resource.emr.auth import ClusterAuthUtils
@@ -25,6 +27,7 @@ class MetricDimension(str, Enum):
     Fault = "Fault"
     Error = "Error"
     Exception = "Exception"
+    ExceptionString = "ExceptionString"
     OperationStartTimeMillis = "OperationStartTimeMillis"
     OperationEndTimeMillis = "OperationEndTimeMillis"
     OperationDurationMillis = "OperationDurationMillis"
@@ -53,6 +56,7 @@ class ServiceMetric:
         self._data[MetricDimension.AccountId.value] = resource_metadata.account_id
         self._data[MetricDimension.EventTimeStampMillis.value] = None
         self._data[MetricDimension.Exception.value] = None
+        self._data[MetricDimension.ExceptionString.value] = None
         self._data[MetricDimension.Error.value] = 0
         self._data[MetricDimension.Fault.value] = 0
         self._data[MetricDimension.Success.value] = None
@@ -69,6 +73,9 @@ class ServiceMetric:
         """
         self._data[MetricDimension.Error.value] = 1
         self._data[MetricDimension.Exception.value] = ex.__class__.__name__
+        # Safe to log AnalyticsLibError details
+        if isinstance(ex, AnalyticsLibError):
+            self._data[MetricDimension.ExceptionString.value] = str(ex)
 
     def set_fault(self, ex: Exception) -> None:
         """
@@ -258,8 +265,10 @@ def records_service_metrics(func):
             ret_val = func(*args, **kwargs)
         except Exception as e:
             if metric is not None:
-                # Note that we're considering all failures (even user-errors) as faults, making the fault metric noisy.
-                metric.set_fault(e)
+                if is_customer_error(e):
+                    metric.set_error(e)
+                else:
+                    metric.set_fault(e)
                 metric.finalize_metric()
                 service_logger.log(metric)
             raise e
@@ -271,3 +280,9 @@ def records_service_metrics(func):
         return ret_val
 
     return wrapper
+
+
+def is_customer_error(e: Exception):
+    return isinstance(e, AnalyticsLibError) or isinstance(
+        e, botocore.exceptions.ClientError
+    )
